<?php

namespace Litecms\Plan\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Litecms\Plan\Http\Requests\PlanUserRequest;
use Litecms\Plan\Interfaces\PlanRepositoryInterface;
use Response;
use User;

class PlanUserController extends UserController
{
    /**
     * Initialize plan controller.
     *
     * @param type PlanRepositoryInterface $plan
     *
     * @return type
     */
    public function __construct(PlanRepositoryInterface $plan)
    {
        $this->model = $plan;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PlanUserRequest $request)
    {
        $plans = $this->model->all();

        $this->theme->prependTitle(trans('plan::plan.names').' :: ');

        return $this->theme->of('plan::user.plan.index', compact('plans'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(PlanUserRequest $request, $role, $id)
    {
        $plan = $this->model->find($id);

        return $this->theme->of('plan::user.plan.show', compact('plan'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PlanUserRequest $request)
    {
        $plan = $this->model->findOrNew(0);

        Former::populate($plan);

        return $this->theme->of('plan::user.plan.create', compact('plan'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PlanUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $plan = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('plan::plan.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(PlanUserRequest $request, $role, $id)
    {
        $plan = $this->model->find($id);

        Former::populate($plan);

        return $this->theme->of('plan::user.plan.edit', compact('plan'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(PlanUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $plan = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('plan::plan.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PlanUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('plan::plan.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
